#
# spec file for package grilo-plugins
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define plugin_dir %(pkg-config --variable plugindir grilo-0.3)
Name:           grilo-plugins
Version:        0.3.16
Release:        150600.1.2
Summary:        Media and metadata plugins for the Grilo framework
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://live.gnome.org/Grilo
Source0:        https://download.gnome.org/sources/grilo-plugins/0.3/%{name}-%{version}.tar.xz

BuildRequires:  docbook_4
BuildRequires:  fdupes
BuildRequires:  gperf
BuildRequires:  intltool >= 0.40.0
BuildRequires:  itstool
BuildRequires:  meson >= 0.44.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(avahi-glib)
BuildRequires:  pkgconfig(avahi-gobject)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.66
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(goa-1.0) >= 3.17.91
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gom-1.0) >= 0.4
BuildRequires:  pkgconfig(grilo-0.3) >= 0.3.10
BuildRequires:  pkgconfig(grilo-net-0.3) >= 0.3.10
BuildRequires:  pkgconfig(grilo-pls-0.3)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libmediaart-2.0)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(lua) >= 5.3.0
BuildRequires:  pkgconfig(oauth)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(totem-plparser) >= 3.4.1
BuildRequires:  pkgconfig(tracker-sparql-3.0) >= 2.99
# Recommend gupnp-plugin-dleyna (UPnP support)
Recommends:     gupnp-plugin-dleyna
%ifarch armv7hl i586
BuildRequires:  gstreamer1(element-chromaprint)
%else
BuildRequires:  gstreamer1(element-chromaprint)()(64bit)
%endif
BuildRequires:  pkgconfig(libdmapsharing-4.0) >= 3.9.9
Obsoletes:      grilo-plugin-youtube <= %{version}

%description
Grilo is a framework for browsing and searching media content from
various sources using a single API.

This package provides plugins for accessing content from various media
providers, including podcasts, Apple trailers, Flickr,
Jamendo, Vimeo, YouTube.

%package -n grilo-plugin-tracker
Summary:        Tracker plugin for the Grilo framework
Group:          Productivity/Multimedia/Other
Supplements:    (grilo-plugins and tracker)

%description -n grilo-plugin-tracker
Grilo is a framework for browsing and searching media content from
various sources using a single API.

%package -n grilo-plugin-dleyna
Summary:        DLNA (dLeyna) plugin for the Grilo media framework
# grilo-plugin-upnp was renamed to dleyna (based on the switch from libupnp to dleyna)
# the plugin interacts with dLeyna on dbus using com.intel.dleyna-server
Group:          Productivity/Multimedia/Other
Requires:       dbus(com.intel.dleyna-server)
Obsoletes:      grilo-plugin-upnp < %{version}
Provides:       grilo-plugin-upnp = %{version}

%description -n grilo-plugin-dleyna
Grilo is a framework for browsing and searching media content from
various sources using a single API.

This package provides a plugin for accessing content from a DLNA
(dLeyna) provider.

%package -n grilo-plugin-youtube
Summary:        Youtube plugin for the Grilo media framework
Group:          Productivity/Multimedia/Other
Supplements:    (grilo-plugins and libgdata)

%description -n grilo-plugin-youtube
Grilo is a framework for browsing and searching media content from
various sources using a single API.

This package provides a plugin for accessing content from Youtube.

%package devel
Summary:        Development files for Grilo plugins
Group:          Development/Libraries/GNOME
Requires:       grilo-plugin-dleyna = %{version}
Requires:       grilo-plugin-tracker = %{version}
#Requires:       grilo-plugin-youtube = %%{version}
Requires:       grilo-plugins = %{version}

%description devel
Grilo is a framework for browsing and searching media content from
various sources using a single API.

This package provides the development files.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}/help

%check
# Temp disable make check for PPC arches as they fail - boo#915682 filed.
%ifnarch ppc64 || ppc64le
# Make check disabled - it fails without network access.
#make check
%endif

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_datadir}/help/C/grilo-plugins/
# Explicitly list plugins
%{plugin_dir}/libgrlbookmarks.so
%{plugin_dir}/libgrlchromaprint.so
%{plugin_dir}/libgrldaap.so
%{plugin_dir}/libgrldpap.so
%{plugin_dir}/libgrlfilesystem.so
%{plugin_dir}/libgrlflickr.so
%{plugin_dir}/libgrlfreebox.so
%{plugin_dir}/libgrlgravatar.so
%{plugin_dir}/libgrlmagnatune.so
%{plugin_dir}/libgrllocalmetadata.so
%{plugin_dir}/libgrlmetadatastore.so
#%%{plugin_dir}/libgrlopensubtitles.so
%{plugin_dir}/libgrlopticalmedia.so
%{plugin_dir}/libgrlpodcasts.so
%{plugin_dir}/libgrlraitv.so
%{plugin_dir}/libgrlshoutcast.so
%{plugin_dir}/libgrlthetvdb.so
%{plugin_dir}/libgrltmdb.so
%{plugin_dir}/libgrlluafactory.so
%dir %{_datadir}/grilo-plugins
%dir %{_datadir}/grilo-plugins/grl-lua-factory
%{_datadir}/grilo-plugins/grl-lua-factory/grl-appletrailers.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-appletrailers.gresource
%{_datadir}/grilo-plugins/grl-lua-factory/grl-euronews.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-euronews.gresource
%{_datadir}/grilo-plugins/grl-lua-factory/grl-guardianvideos.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-guardianvideos.gresource
%{_datadir}/grilo-plugins/grl-lua-factory/grl-acoustid.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-itunes-podcast.gresource
%{_datadir}/grilo-plugins/grl-lua-factory/grl-itunes-podcast.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-thegamesdb.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-musicbrainz-coverart.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-radiofrance.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-radiofrance.gresource
%{_datadir}/grilo-plugins/grl-lua-factory/grl-video-title-parsing.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-lastfm-cover.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-steam-store.lua
%{_datadir}/grilo-plugins/grl-lua-factory/grl-theaudiodb-cover.lua

%files lang -f %{name}.lang

%files -n grilo-plugin-tracker
%{plugin_dir}/libgrltracker3.so

%files -n grilo-plugin-dleyna
%{plugin_dir}/libgrldleyna.so

#%%files -n grilo-plugin-youtube
#%%{plugin_dir}/libgrlyoutube.so

%files devel
%{_datadir}/help/*/examples/
%{_libdir}/pkgconfig/grilo-plugins-0.3.pc

%changelog
* Tue Apr  4 2023 bjorn.lie@gmail.com
- Update to version 0.3.16:
  + tracker3: update fts query
  + dmap: enable with libsoup3 supported libdmapsharing-4.0
  + lua-factory: add support to 5.4
  + build: libsoup3 related fixes
  + flickr: remove GOA support
  + tmdb: without config, fix single request
  + Updated translations.
- Drop d1c0835d.patch: Fixed upstream.
* Wed Mar  8 2023 bjorn.lie@gmail.com
- Build dmap plugins again now that libdmapsharing have been
  updated to use soup-3. Drop pkgconfig(libgdata) BuildRequires.
- Add grilo-plugin-youtube Obsoletes: Make updates painless for our
  end-users.
* Fri Sep 23 2022 bjorn.lie@gmail.com
- Switch to soup3 again: Drop pkgconfig(libsoup-2.4) and
  pkgconfig(rest-0.7), and disable pkgconfig(libgdata) and enable
  pkgconfig(libsoup-3.0) BuildRequires and stop building youtube,
  opensubtile and dmap plugins for now. Pass enable-dmap=no to
  meson, as this is needed.
* Tue Sep 13 2022 bjorn.lie@gmail.com
- Add d1c0835d.patch: flickr: remove GOA support. GNOME Online
  accounts removed flicker backend so we need to remove it here
  too.
* Mon Aug 29 2022 bjorn.lie@gmail.com
- Add back pkgconfig(libsoup-2.4) and disable
  pkgconfig(libsoup-3.0) BuildRequires, build youtube and
  opensubtile plugins again, grilo and grilo plugins are not ready
  to move to soup3.
* Mon Aug 22 2022 dimstar@opensuse.org
- Update to version 0.3.15:
  + Detect libsoup version from grl-net and adds support to
    libsoup3.
  + youtube: port to API v3 by using libgdata 0.17.0.
  + tmdb: port to GUri, remove libsoup dependency.
  + dleyna: port to GUri, remove libsoup dependency.
- youtube and opensubtile plugins currently not being built, as
  they are not yet compatible with libsoup 3.
* Wed Oct  6 2021 dimstar@opensuse.org
- Update to version 0.3.14:
  + Fix lua-factory crash on >= 5.4.3.
  + Clarify LGPLv2.1 or later license.
  + tracker3: Make resolve async.
  + euronews: Use YouTube feeds.
  + Updated translations.
- Drop 108.patch: fixed upstream.
* Tue Apr 20 2021 dimstar@opensuse.org
- Add 108.patch: lua-factory: Remove a bad pop. This was exposed
  by Lua 5.4.3, causing a crash.
* Sat Apr 17 2021 dimstar@opensuse.org
- Update to version 0.3.13:
  + Remove Vimeo plugin.
  + Remove Jamendo plugin.
  + Deprecate: tracker version 2.
  + guardianvideos: Use api-key from GrlConfig.
  + thegamesdb: Update the Dreamcast MIME type.
  + tracker3: Handle delete events better.
  + tracker3: Fix setting of publication-date metadata-key.
  + Add option to disable bulding help.
  + Allow building grilo-plugins as a Meson subproject.
* Mon Sep  7 2020 dimstar@opensuse.org
- Switch to Tracker 3:
  + Drop tracker-devel BuildRequires: redundant dependency.
  + Replace pkgconfig(tracker-sparql-2.0) BuildRequires with
    pkgconfig(tracker-sparql-3.0).
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 0.3.12:
  + Add Tracker3 plugin.
  + tracker3: Add support to run under Flatpak.
  + tracker3: Prefer last-modified from file's metadata.
  + Remove Spotify coverart plugin.
  + dmap: Add support to libdmapsharing-4.0.
  + Stream Store: Fix date format to iso8601.
  + tracker: Add Genre fetched from tracker.
  + dleyna: Allow bus name to be changed.
  + dleyna: Set metadata relative to containers' type.
  + Acoustid: Fix the counting of Release Groups.
  + Acoustid: Fix returning same Record multiple times.
  + Lua-Factory: Add support to GrlRelatedKeys.
  + Updated translations.
- Replace pkgconfig(libdmapsharing-3.0) BuildRequires with
  pkgconfig(libdmapsharing-4.0): move to the newer supported API.
* Fri Apr 17 2020 mgorse@suse.com
- Remove use of is_opensuse. Chromaprint and libdmapsharing3 are
  now built in SLE-15-SP2 (jsc#SLE-11723).
* Fri Feb 14 2020 bjorn.lie@gmail.com
- Update to version 0.3.11:
  + tracker:
  - Fix crash if chromaprint plugin isn't installed.
  - Correctly escape strings on sparql updates.
  - Acoustid: add support for album artist.
  + Updated translations.
- Drop tracker-fix-crash-if-chromaprint-plugin-not-installed.patch:
  Fixed upstream.
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Fri Dec  6 2019 yfjiang@suse.com
- Add tracker-fix-crash-if-chromaprint-plugin-not-installed.patch:
  avoid crash if the chromaprint is disabled on build time
  (bsc#1158231 glgo#GNOME/grilo-plugins#61).
* Sat Sep 14 2019 bjorn.lie@gmail.com
- Update to version 0.3.10:
  + Tracker plugin now requires >= 2.3.0.
  + Convert README to Markdown.
  + Tracker:
  - Implement source notification through TrackerNotifier.
  - Mark playlists as a container.
  - Use the correct property to retrieve album title.
  - Use tracker:ExternalReference to retrieve musicbrainz ids.
  + Chromaprint: Throw an error on missing decoders.
  + Lua-Factory:
  - Renamed grl-musicbrainz to grl-musicbrainz-coverart
  - Acoustid:
    . Return Multiple Results from AcoustID Plugin.
    . Add support for creation_date.
    . Return from source in case of no match.
  - TheAudioDB: Add the ability to retrieve artist art.
  + Updated translations.
- Add explicit pkgconfig(tracker-sparql-2.0) BuildRequires: It is
  already pulled in, but since meson checks for it, we add it.
* Tue Jul 16 2019 bjorn.lie@gmail.com
- Update to version 0.3.8:
  + Require Grilo >= 0.3.8.
  + Lua enabled by default.
  + Lua-Factory:
  - Fix parameter order in grl.fetch().
  - Add Steam Store plugin.
  - Remove Metrolyrics plugin.
  - Remove Pocket plugin.
  - Rename grl-musicbrainz to grl-musicbrainz-coverart.
  + TheGamesDB: Add Sega Pico and SG-1000 MIME types.
  + Euronews: Use https instead of http.
  + Video title parsing: Fix setting empty titles.
  + AcoustID:
  - Sort records by submissions count instead of submission date.
  - Add support for album-disc-number, publication-date,
    track-number.
  - Add support for creation-date.
  - MusicBrainz Coverart: Use mb-release-id instead of
    mb-album-id for better accuracy.
  + Bookmarks: Fix adding duplicated entry.
  + Podcasts: Fix crash when parsing unsupported format.
  + Optical Media: Add "ignored-scheme" configuration.
  + Tracker:
  - Fix last played mapping.
  - Add mapping from tracker for MusicBrainz IDs.
  - Mark playlists as containers in Grilo.
  - Remove per-device-source configuration.
  - Rewrite tracker GrlSource notification to use
    TrackerNotifier.
  + Added translations in help.
  + Updated translations.
* Wed Oct 17 2018 jengelh@inai.de
- Avoid em dashes in summaries.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 0.3.8:
  + Autotools removed.
  + Add pkgconfig file.
  + meson: Fixes finding lua-5.3 in FreeBSD.
  + Tracker: Fixes error types (bgo#794691).
  + Lua-Factory:
  - New source: TheAudioDB cover source
  - AcoustID: Add support to MusicBrainz' release and
    release-group.
  - MusicBrainz: Add support to release-group cover art.
  + Updated translations.
- Add meson BuildRequires and corresponding macros as well as
  autosetup, following upstreams changes to meson buildsystem.
- Add devel sub package following upstream changes.
- Add fdupes BuildRequires and macro, remove duplicates.
- Drop pkgconfig(gmime-3.0) BuildRequires: No longer needed, nor
  used.
- Add grilo-plugin-upnp Provides to grilo-plugin-dleyna
  sub-package, Obsoletes is already in place.
* Fri Jul 27 2018 bjorn.lie@gmail.com
- Update to version 0.3.7:
  + Last release with autotools
  + Meson: Fix Lua sourcers directory.
  + Lua-Factory:
  - Allow lua sources to register metadata-keys.
  - The Games DB: Add developer, publisher, coop and players
    metadata information with is own metata-keys.
* Tue Jul 17 2018 bjorn.lie@gmail.com
- Update to version 0.3.6:
  + Gravatar plugin: Fix memory leak.
  + Opensubtitles: Fix memory leak.
  + Lua-Factory:
  - Replace assert() with critical messages.
  - Apple trailers - Fix warnings.
  - itunes podcast - Fix maximum items.
  - The Games DB:
    . Add support to TurboGrafx-CD
    . Add support to Neo-Geo Pocket Color
    . Add support to WonderSwan and WonderSwan Color
    . Add support to Famicom
    . Add support to Atari Lynx
    . Add support to Virtual Boy
    . Fix multiple Genres per game
  + Magnatue: Add cover art support.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Dec  7 2017 fcrozat@suse.com
- Disable chroma and dmapsharing when building on SLE (not
  available there).
* Thu Sep 14 2017 fezhang@suse.com
- Drop SLE12 / Leap42 build conditionals, enable lua and chroma
  unconditionally.
* Fri Aug 25 2017 zaitor@opensuse.org
- Update to version 0.3.5:
  + build: bgo#778858: meson: Fix library name of optical-media
    plugin.
  + dmap plugin: bgo#781278: Fix DMAP plugins not loading.
  + flickr plugin: bgo#707643: flickr: populate GrlMediaImage with
    EXIF data.
  + lastfm-cover plugin: bgo#766789: Use HTTPS rather then insecure
    HTTP.
  + lua-factory plugin:
  - bgo#778857: Building lua-factory breaks with gperf 3.1 if
    builddir != srcdir.
  - bgo#779444: Fix a few leaks in plugins.
  - bgo#781318: Fix lua sources path with Meson.
  + tracker plugin: bgo#786602: [Tracker] Use sparql1.1 "AS ?var"
    syntax.
- Drop grilo-plugins-tracker-2.0.patch: Fixed upstream, following
  this, drop gnomec-common BuildRequires and autoreconf call, no
  longer needed.
- Drop obsolete clean section.
- Replace pkgconfig(gmime-2.6) with pkgconfig(gmime-3.0)
  BuildRequires: Needed for podcast support.
- Pass --enable-podcasts to configure, ensure we are building
  podcast support.
* Fri Jul 21 2017 dimstar@opensuse.org
- Add grilo-plugins-tracker-2.0.patch: Also detect tracker 2.0 as
  a valid option.
- Add gnomec-common BuildRequires and call autoreconf, as above
  patch touches the buildsystem.
* Tue Feb 14 2017 zaitor@opensuse.org
- Update to version 0.3.4:
  + General: Add support for Meson build.
  + Bugs fixed: bgo#775957, bgo#770959, bgo#777210, bgo#771446,
    bgo#771445, bgo#773702, bgo#775957, bgo#778596, bgo#775561,
    bgo#773310, bgo#776482, bgo#770806, bgo#774748.
  + Updated translations.
- Add gperf BuildRequires: New "optional" dependency.
* Tue Jan 24 2017 zaitor@opensuse.org
- Add armv7hl to conditional gstreamer1(element-chromaprint)
  BuildRequires: Build for armv7.
* Sat Sep 10 2016 zaitor@opensuse.org
- Update to version 0.3.3:
  + Bugs fixed: bgo#768520, bgo#768185, bgo#768606, bgo#768093,
    bgo#769331, bgo#770806, bgo#769347, bgo#769349, bgo#769356,
    bgo#769357, bgo#769373, bgo#767684, bgo#770806.
* Fri Aug 26 2016 dimstar@opensuse.org
- Conditionally disable LUA Factory on openSUSE < 13.2 (SLE and
  Leap 42.x). LUA 5.3 is not available and as a consequence we
  can't ship LUA Factory plugins.
- Conditionally disabled chromaprint on openSUSE < 13.2 (SLE and
  Leap 42.x). GStreamer/chroma support is not available.
* Fri Jun 17 2016 zaitor@opensuse.org
- Update to version 0.3.2:
  + Bugs fixed: bgo#732879, bgo#732879, bgo#764486, bgo#764077,
    bgo#764078, bgo#764814, bgo#764816, bgo#766678, bgo#767631,
    bgo#764078, bgo#764814, bgo#764600, bgo#766678, bgo#764486,
    bgo#761624, bgo#761869, bgo#766587.
- Add pkgconfig(gstreamer-1.0) and
  pkgconfig(gstreamer-plugins-bad-1.0) BuildRequires: New
  dependencies needed for the new chromaprint support. Also pass
  - -enable-chromaprint to configure to ensure the support is built.
- Following the above add gstreamer1(element-chromaprint)()(64bit)/
  gstreamer1(element-chromaprint) BuildRequires. This should not be
  needed, and future investigation if the bug is in grilo-plugins
  or gstreamer-plugins-bad is needed.
- Drop grilo-plugins-Fix-gcc6-build.patch: Fixed upstream.
* Thu Jun 16 2016 zaitor@opensuse.org
- Add grilo-plugins-Fix-gcc6-build.patch: Fix build with GCC 6,
  patch from upstream.
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 0.3.1:
  + Tracker plugin:
  - Fix handling of keys with underscores in their names
    (bgo#761168).
  - Fix giving back wrong type of media that was causing crashes
    in GNOME Videos (bgo#761168).
  + Lua Factory plugin:
  - Make containers match any supported_media (bgo#760378).
  - Fix double-free when handling GOA accounts (bgo#760565).
  - Fix warnings when the requested keys in the source table,
    stop lua plugins from changing input arguments, better source
    tracking to avoid memory leaks (bgo#753141, bgo#732879,
    bgo#763046).
  - Order last.fm thumbnails from large to small (bgo#761694).
  - Don't warn for unknown keys in source table (bgo#732879).
  + TheTVDB plugin: Require a newer gom that fixes migration
    problems (bgo#759835).
* Tue Dec 22 2015 damjanovic.ivo@gmail.com
- Update to version 0.3.0:
  + General:
  - Fix tests.
  - Add more tests.
  - Remove XML descriptions.
  - Use the new 0.3 API.
  - bgo#749063: build: General git.mk and MAINTAINERCLEANFILES
    fixes.
  - bgo#754531: Make lua-factory a hard requirement.
  - bgo#755551: remove media specifiers as subclasses.
  - bgo#755702: Show better configuration information.
  - bgo#759295: Get rid of XML plugins descriptors.
  + Apple Trailers plugin: Port Apple Trailers source to Lua
    (bgo#752681)
  + Bliptv plugin:
  - Remove it (Blip.tv service was shutdown).
  - Search return recent items' RSS instead of results
    (bgo#725031).
  + Bookmarks plugin: grl-bookmarks doesn't notify of removals
    (bgo#752066).
  + dLeyna plugin:
  - Fix grl_dleyna_util_uri_is_localhost() usage (bgo#749889).
  - Fix incorrect properties passed to applications (bgo#749890).
  + DMAP plugin: Add DPAP (iPhoto sharing) plugin (bgo#746722).
  + Filesystem plugin: weird content-changed notifications
    (bgo#755181).
  + Freebox plugin: radios.m3u missing in the 0.2.14 tarball,
    build fails (bgo#745179).
  + Guardianvideos plugin:
  - fix URL format string (bgo#748224).
  - Fix unescaping Guardian Videos titles (bgo#750990).
  + Last.fm Albumart plugin:
  - Port to Lua.
  - lastfm: update to new API 2.0 (bgo#700276).
  + Local Metadata plugin:
  - Remove unused variable (bgo#746776).
  - Don't crash on files named wsb.wmv (bgo#748604).
  - Query for media art existence (bgo#752057).
  - Remove title parsing from local-metadata plugin (bgo#754532).
  - local-metadata: Another bad TV show parsing (bgo#755464).
  + Lua Factory plugin:
  - WIP: Use lua to parse video titles (bgo#741607).
  - lua-factory: testing (bgo#741784).
  - Information leak via plain text HTTP connection (bgo#747953).
  - Make it easier to access the API key config (bgo#750903).
  - CRITICAL **: grl_l_callback: assertion 'os != NULL' failed
    (bgo#750955).
  - Better sandboxing (bgo#750982).
  - Add inspect.lua helper (bgo#750983).
  - Fix possible memleak if source registration fails
    (bgo#751786).
  - Add support for GOA in lua-factory (bgo#751981).
  - Add support for dates in Epoch format (bgo#752593).
  - tests: Fix lua-factory Makefile generation (bgo#752594).
  - Add grl.is_video_site() function (bgo#752595).
  - Also try convert HTML from ISO8859-1 (bgo#752895).
  - Re-add "Music" GOA support (bgo#752899).
  - Fix compilation with g-o-a disabled (bgo#754895).
  - Add XML parser (bgo#755556).
  + Magnatune plugin: Magnatune plugin doesn't invoke the callback
    in search operations with 0 result (bgo#751890).
  + Metadata Store plugin: "last-played-time" declared as string,
    instead of date-time (bgo#686175).
  + Metrolyrics plugin:
  - Fix metrolyrics source and test (bgo#754275).
  - Fix parser after metrolyrics changes (bgo#759109).
  + Opensubtitles plugin: Opensubtitles plugin causes many
    warnings (bgo#754451).
  + Pocket plugin: Port to Lua.
  + Spotify plugin:
  - Add Spotify albumart plugin.
  - Implement Spotify plugin (bgo#754811).
  + TheTVDB plugin:
  - Make it possible to hit only cache (bgo#748422).
  - Fuzzy series name matching (bgo#748423).
  - use https rather than insecure http (bgo#754489).
  - Force updating the show name (bgo#758959).
  + Tracker plugin:
  - "last-played-time" declared as string, instead of date-time
    (bgo#686175).
  - rhythmbox crashes with SIGSEGV in
    tracker_evt_update_orphan_item_cb (bgo#733582).
  - Tracker plugin's change signal is useless (bgo#746974).
  - Do not advertise browse support for the Tracker extractor
    (bgo#748173).
  - Eliminate duplicates in grl-tracker search results
    (bgo#748539).
  - track number is missing from grilo information (bgo#753732).
  - Fix tracker serialisation (bgo#758654).
  + Vimeo: Fix distcheck.
  + Youtube plugin:
  - Home-made refcounting?! (bgo#741634).
  - Update libgdata API usage (bgo#748395).
  - Grilo YouTube plugin crash (bgo#754244).
  + Updated translations.
- Update BuildRequires for grilo 0.3 port:
  + Removed: pkgconfig(grilo-0.2), pkgconfig(grilo-net-0.2) and
    pkgconfig(grilo-pls-0.2)
  + Added: pkgconfig(grilo-0.3), pkgconfig(grilo-net-0.3) and
    pkgconfig(grilo-pls-0.3)
- Drop --enable-pocket configure parameter: no longer recognized
  after the port of the pocket plugin to LUA.
- Drop --enable-raitv configure parameter: it is auto detected and
  we realize it missing if the file list changes.
* Sun Dec 20 2015 zaitor@opensuse.org
- Update to version 0.2.17:
  + bgo#755702: Show better configuration information.
  + bgo#755181: filesystem: weird content-changed notifications.
  + bgo#754532: Remove title parsing from local-metadata plugin.
  + bgo#755464: local-metadata: Another bad TV show parsing.
  + bgo#700276: lastfm: update to new API 2.0.
  + bgo#754531: Make lua-factory a hard requirement.
  + bgo#754811: spotify: implement Spotify plugin.
  + bgo#755556: Add XML parser.
  + bgo#759109: metrolyrics: fix parser after metrolyrics changes.
  + bgo#758959: thetvdb: Force updating the show name.
  + bgo#746974: Tracker plugin's change signal is useless.
  + bgo#758654: Fix tracker serialisation.
  + Updated translations.
* Thu Sep 24 2015 zaitor@opensuse.org
- Update to version 0.2.16:
  + lastfm: update to new API 2.0 (bgo#700276).
  + lua-factory: Fix compilation with g-o-a disabled (bgo#754895).
  + TheTVDB plugin: Fix tests.
* Thu Sep 10 2015 dimstar@opensuse.org
- Update to version 0.2.15:
  + Lot of improvements in Lua Factory.
  + Removed Blip.tv source (service shutdown).
  + Apple Trailers plugin ported to Lua.
  + Pocket plugin ported to Lua.
  + General: build: General git.mk and MAINTAINERCLEANFILES fixes
    (bgo#749063).
  + Apple Trailers plugin: Port Apple Trailers source to Lua
    (bgo#752681).
  * Blip.tv plugin: bliptv: Search return recent items' RSS instead
    of results (bgo#725031).
  + Bookmarks plugin: grl-bookmarks doesn't notify of removals
    (bgo#752066).
  + dLeyna plugin
  - bgo#749889: Fix grl_dleyna_util_uri_is_localhost() usage.
  - bgo#749890: Fix incorrect properties passed to applications.
  + DMAP plugin: Add DPAP (iPhoto sharing) plugin (bgo#746722).
  + Freebox plugin: radios.m3u missing in the 0.2.14 tarball, build
    fails (bgo#745179).
  + Guardian Videos plugin:
  - BGO#748224: fix URL format string.
  - BGO#750990: Fix unescaping Guardian Videos titles.
  + Local Mmetadata plugin:
  - bgo#746776: Remove unused variable.
  - bgo#748604: Don't crash on files named wsb.wmv.
  - bgo#752057: Query for media art existence.
  + Lua Factory plugin: Bugs fixed: bgo#741607, bgo#741784,
    bgo#747953, bgo#750903, bgo#750955, bgo#750982, bgo#750983,
    bgo#750990, bgo#751786, bgo#751981, bgo#752593, bgo#752594,
    bgo#752595, bgo#752681, bgo#752895, bgo#752899.
  + Magnatune plugin: - Magnatune plugin doesn't invoke the
    callback in search operations with 0 result (bgo#751890).
  + Metrolyrics plugin: Fix metrolyrics source and test
    (bgo#754275).
  + OpenSubtitles plugin: Opensubtitles plugin causes many warnings
    (bgo#754451).
  + TheTVDB plugin:
  - bgo#748422: Make it possible to hit only cache.
  - bgo#748423: Fuzzy series name matching.
  - bgo#754489: use https rather than insecure http.
  + Tracker plugin:
  - bgo#733582: rhythmbox crashes with SIGSEGV in
    tracker_evt_update_orphan_item_cb.
  - bgo#748173: Do not advertise browse support for the Tracker
    extractor.
  - bgo#748539: Eliminate duplicates in grl-tracker search
    results.
  - bgo#753732: track number is missing from grilo information.
  + YouTube plugin:
  - bgo#741634: Home-made refcounting?!
  - bgo#748395: Update libgdata API usage.
  - bgo#754244: Grilo YouTube plugin crash.
  + Updated translations.
* Wed Feb 18 2015 dimstar@opensuse.org
- Update to version 0.2.14:
  + General:
  - bgo#724308: Make it possible to pass "flags" to "remove().
  - bgo#725148: Automatic network awareness.
  - bgo#740942: core: Fix excessive ref'ing when registering new
    keys.
  - bgo#740943: core: Add register_keys plugin function.
  - bgo#741207: Minor fixes at local-metadata and thetvdb.
  - bgo#743449: Use HTTPS whenever possible.
  + Bookmarks plugin:
  - Fix thumbnail URL not getting saved.
  - Fix updating bookmarks.
  - Emit "item-removed" only when item is actually removed.
  + dLeyna plugin: Crash in the dLeyna plugin (bgo#740052).
  + Euronews source: Folder icons for Euronews and The Guardian
    Videos (bgo#736548).
  + Flickr plugin: Small fixes.
  + Freebox plugin: core: Add "audio-track" property (bgo#744168).
  + Local Metadata plugin:
  - bgo#740927: Add support for getting gibest hash.
  - bgo#741562: Broken title with another TV episode format.
  + Lua Factory plugin:
  - bgo#725147: Support embedded resources.
  - bgo#729680: Some HTML entities not unescaped by
    grl.unescape().
  - bgo#737169: Avoid warning if fetching an item failed.
  - bgo#739508: Warn when dates are in an invalid format.
  - bgo#740761: Correct "file size" metadata key.
  - bgo#740765: Fix use-after-free.
  - bgo#740928: Add support for boolean media properties.
  - bgo#742523: Work-around websites that still use ISO8859-1.
  - bgo#744353: may_resolve doesn't handle media being NULL.
  + OpenSubtitles plugin: opensubtitles: Add plugin (bgo#740871).
  + Podcasts plugin: Fix crasher when DB could not be opened
    (bgo#741258).
  + Radiofrance source:
  - Support EPG down.
  - Added icon.
  + TheTVDB plugin: Unset "title-from-filename" when changing title
    (bgo#740763).
  + TMDb plugin:
  - bgo#739502: Don't try to resolve TV series.
  - bgo#740763: Unset "title-from-filename" when changing title.
  - bgo#743316: Add libsoup as dependency to tmdb plugin in
    configure.ac.
  + Tracker plugin
  - bgo#740707: Add range filter support.
  - bgo#740756: Correctly set "title-from-filename".
  - bgo#740761: Correct "file size" metadata key.
  + The Guardian Videos source:
  - bgo#736548: Folder icons for Euronews and The Guardian
    Videos.
  - bgo#737176: Update for new API.
  + YouTube plugin
  - Small fixes.
  - bgo#744015: Remove code supporting libgdata < 0.9.1.
  + Updated translations.
- Enable pkgconfig(libmediaart-2.0) BuildRequires: upstream ported
  the code completely.
* Sat Jan 31 2015 zaitor@opensuse.org
- Disable make check for PPC64 and PPC64le arches (boo#915682).
  Fixes build for PPC arches on a temporarly basis.
* Sat Dec 20 2014 zaitor@opensuse.org
- Replace pkgconfig(libmediaart-1.0) for pkgconfig(libmediaart-2.0)
  BuildRequirs, but disabled for now, as upstream has not ported
  to the new api.
* Sat Oct 11 2014 vuntz@opensuse.org
- Add avahi-client, avahi-glib and avahi-gobject pkg-config
  BuildRequires, to allow building the freebox plugin.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 0.2.13:
  + Several fixes in build system.
  + Generate AUTHORS file automatically.
  + bgo#706877: Let TheMovieDb resolver perform searches based on
    file name.
  + bgo#727901: Some filesystem plugin related build fixes.
  + Bookmarks plugin:
  - Reimplemented using GOM as backend, instead of SQLite
    directly.
  - bgo#729787: Application crashes at startup.
  + dLeyna plugin:
  - New plugin based on dLeyna to access UPnP/DLNA sources.
  - bgo#707346: dleyna: Plugin to access DLNA contents using the
    dLeyna DBus service.
  - bgo#732016: Bad string construction.
  - bgo#733253: UPnP/DLeyna bug fixes.
  + Filesystem plugin
  - bgo#725203: Filesystem plugin bug fixes.
  - bgo#730841: grl-file-system: no notification changes for root
    container.
  + Flickr plugin: bgo#730812: flickr: Use SSL.
  + Jamendo plugin:
  - Fix browsing root category.
  - Fix wrong free.
  + LastFM Album Art plugin: Added tests.
  + Local Metadata plugin:
  - bgo#725025: local-metadata: Movies detected as episodes of a
    series.
  - bgo#725026: Add support for SeasonxEpisode filename format.
  - bgo#725456: grilo sometimes calls plugins with %%20 instead of
    spaces.
  - bgo#727181: local-metadata: Another bad TV show parsing.
  - bgo#732261: local-metadata: new regexp match.
  - bgo#734636 Tracker plugin doesn't get thumbnails.
  + Lua Factory plugin:
  - Several fixes.
  - bgo#750038: Conditional operator does not typecheck.
  - bgo#727570: Fix typo in debug statement.
  - bgo#727571: Don't add duplicate sources.
  - bgo#728525: Add grl.unzip fetch function.
  - bgo#728882: Add more keys to grl.get_options().
  - bgo#729649: Fix garbage after escaped text in grl.unescape().
  - bgo#733259: Fix use after free.
  - bgo#733289: don't iterate on lua env table.
  - bgo#733303: GrlMediaBoxes cannot have their metadata
    resolved.
  - Euronews source: bgo#731224: Crash in can_remove if
    g_uri_parse_scheme fails.
  - Musicbrainz source: bgo#727766: Add Musicbrainz Cover Art
    plugin.
  - Radiofrance source:
    . bgo#727569: Don't break when run behind a portal.
    . bgo#734234: RadioFrance source does not work in grilo.
  + Optical Media plugin: bgo#729704: Fix physical optical drives
    being ignored.
  + Pocket plugin: Request librest >= 0.7.90.
  + TheTVDB plugin:
  - bgo#672933: Add thetvdb.com metadata.
  - bgo#733287: thetvdb: fetch show in cache with case
    insensitive.
  + Tracker plugin:
  - Add deinit() function.
  - bgo#678519: grl_media_source_get_media_from_uri not
    implemented for tracker media source plugin.
  - bgo#701651: Use OpenSubtitles.org to look up IMDB ID.
  - bgo#730399: Search strings should be escaped.
  + UPnP plugin:
  - Removed this plugin, replaced by new dLeyna plugin.
  - bgo#723780: upnp: filter out devices on the local machine.
  - bgo#733253: UPnP/DLeyna bug fixes.
  + Vimeo plugin
  - bgo#727899: vimeo: Remove libgcrypt dependency.
  - bgo#730900: Vimeo not work!
  + Updated translations.
- Rename grilo-plugin-upnp subpackage to grilo-plugin-dleyna,
  following upstreams switch of the underlying infrastructure.
  + Obsolete grilo-plugin-upnp by grio-plugin-dleyna.
  + Require dbus(com.intel.dleyna-server).
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 0.2.12:
  + bgo#725299: build: Detect Lua in Debian systems.
  + bgo#725420: all: Add names to all the timeouts and idles.
  + Apple Trailers plugin: core: Add "source-tags" property
    (bgo#724019).
  + Bookmarks plugin: Pass the removed media when notifying
    (bgo#726349).
  + Filesystem plugin: bug fixes (bgo#725203).
  + Freebox plugin: Add "source-tags" property (bgo#724019).
  + Guardian plugin:
  - Removed (part of new Lua Factory plugin).
  - guardian-videos: Update to use guardianapis (bgo#724644).
  + Local Metadata plugin:
  - Added tests.
  - local-art: Use libmediaart instead of custom code
    (bgo#724046).
  - Add support for SeasonxEpisode filename format (bgo#725026).
  + Lua Factory plugin:
  - Added new plugin that allows to create sources in Lua
    language.
  - It includes the following sources:
    . Euronews - A source for watching Euronews online.
    . Metrolyrics - A source for lyrics.
    . Radio France - A source for browsing Radio France radio
    stations.
    . The Guardian Videos - A source for browsing videos from the
    Guardian.
  - Bugs fixed: bgo#711243, bgo#722820, bgo#724415, bgo#724644,
    bgo#725188, bgo#725209, bgo#725381, bgo#726562, bgo#726563,
    bgo#726677.
  + Pocket plugin: initialize variables (bgo#725425).
  + TMDb plugin: Fix possible assertion at run-time (bgo#726372).
  + Tracker plugin: Add GRL_METADATA_KEY_SIZE (bgo#629002).
  + UPnP plugin: Prevent crash with some UPnP servers (bgo#724793).
  + Plug some leaks.
  + Updated translations.
- Add pkgconfig(lua) and pkgconfig(libmediaart-1.0) BuildRequires:
  new dependencies.
- Pass --enable-lua-factory to configure: ensure to fail the build
  should we miss LUA support.
* Fri Feb 28 2014 dimstar@opensuse.org
- Enable pocket plugin:
  + Pass --enable-pocket to configure.
  + Add pkgconfig(rest-0.7) BuildRequires.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 0.2.11:
  + General: Require glib >= 2.34.
  + Bookmarks plugin: Bug fixes (bgo#724548).
  + Flickr plugin: Set mime-type for images (bgo#724615).
  + Freebox plugin: freebox plugin fails to link against avahi-glib
    and avahi-client (bgo#724369).
  + Pocket plugin:
  - Bump required gnome-online-accounts version (bgo#724123).
  - Add thumbnails support for videos (bgo#724265).
  + TMDb plugin: Fix tests.
  + Tracker plugin: grl-tracker-source cannot find tracker 1.0
    (bgo#724546).
  + Updated translations.
* Tue Feb 11 2014 dimstar@opensuse.org
- Update to version 0.2.10:
  + General
  - Improve building.
  - Require glib 2.32 or higher.
  - Require new Grilo version.
  - Run coverage only in src/.
  - Unload plugins in tests.
  + Apple Trailers plugin
  - Do not share GCancellable among operations.
  - bgo#722398: core: Add unit to duration.
  - bgo#723233: Add source icons.
  + Blip.tv plugin
  - Fixed leak.
  - Small fixes.
  - bgo#723233: Add source icons.
  + Bookmarks plugin: Small fixes.
  + DMAP plugin:
  - Add more attributes.
  - Small fixes.
  - bgo#715016: dmap: Fix memory leak when Avahi is absent.
  - bgo#723574: Patch to make DMAP media list hierarchical.
  + Fake Metadata plugin: Removed plugin.
  + Filesystem plugin:
  - bgo#695303: new feature: grilo playlist library.
  - bgo#709900: Don’t return outdated thumbnails for local files.
  - bgo#710796: Minor memory leak fix.
  + Flickr plugin
  - Small fixes.
  - bgo#706917: flickr: resolve() returns wrong values.
  + Freebox plugin:
  - New plugin offering TV channels through Freebox server,
    offered by Free ISP in France.
  - bgo#720436: freebox: Add new Freebox TV source.
  + Gravatar plugin: Fix typo in error message (bgo#715017).
  + Guardian plugin:
  - New plugin showing the newest videos from the Guardian.
  - bgo#680678: Add Guardian Video source.
  + Jamendo plugin: Assorted fixes from coverity scan (bgo#721642).
  + Magnatune plugin: Small fixes.
  + Optical Media plugin:
  - bgo#703619: Create sources for each optical media.
  - bgo#720441: Fix CFLAGS and LIBS name.
  - bgo#722629: Implement proper content-changed support.
  - bgo#723990: Fix incorrect emblemed icon handling.
  + Pocket plugin
  * New plugin showing content from Pocket.
  * bgo#722819: Add Pocket source.
  + Rai.tv plugin:
  - Fixed leaks.
  - Small fixes.
  - bgo#721642: Assorted fixes from coverity scan.
  - bgo#722822: raitv: Remove slow keys.
  - bgo#723233: Add source icons.
  + TMDb plugin:
  - Fixed tests.
  - bgo#710185: grilo-inspect leaves empty directories in /tmp.
  - bgo#710272: Test-suite fails with libsoup 2.44.1.
  - bgo#721642: Assorted fixes from coverity scan.
  - bgo#723147: tmdb: Use https queries.
  - bgo#723149: tmdb: Reduce number of network calls.
  + Tracker plugin: Support 0.17 and tracker 0.18 (bgo#715036 and
    bgo#715080).
  + UPnP plugin: Add icons for UPnP servers (bgo#722607).
  + Vimeo plugin:
  - Added new tests.
  - Fixed leaks.
  - bgo#711393: Don't leak cache directories.
  - bgo#723233: Add source icons.
  + YouTube plugin
  - Fix management of skip value.
  - More debug information.
  - Small fixes.
  - bgo#721642: Assorted fixes from coverity scan.
  - bgo#723233: Add source icons.
  + Bugs fixed: bgo#699317, bgo#710185, bgo#723525.
  + Updated translations.
- Drop grilo-plugins-tracker-0.18.patch and
  grilo-plugins-testsuite.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh: we
  no longer carry patches.
* Sat Nov 23 2013 dimstar@opensuse.org
- Add grilo-plugins-tracker-0.18.patch: Detect tracker 0.18.
- Add libtool BuildRequires, as above patch touches the build
  system.
* Tue Oct 29 2013 dimstar@opensuse.org
- Add grilo-plugins-testsuite.patch: Fix test suite with libsoup
  2.44.1.
* Mon Aug 26 2013 dimstar@opensuse.org
- Update to version 0.2.9:
  + Added lcov support (test coverage).
  + Integration with Coveralls.io service.
  + Refactored testsuite to use glib gtester.
  + Apple trailers plugin:
  - Fixed warning.
  - Added test suite.
  + Blip.tv plugin:
  - Fixed problems with pagination.
  - Check empty results case.
  - Added test suite.
  + Flickr plugin:  Bigger thumbnails (bgo#705149).
  + Local Metadata plugin:
  - Added new tests.
  - Fixed leaks.
  + Magnatune plugin: slow startup due to hostname lookup at plugin
    init (bgo#701336).
  + TMDb plugin: Small fixes.
  + UPnP plugin:
  - Use always root container when browsing using search.
  - Disappearing sources are not unregistered (bgo#702730).
  - Avoid warning on empty resolve result (bgo#704917).
  + Vimeo plugin: Added test suite.
  + Bugs fixed: bgo#702731, bgo#703037, bgo#703396.
  + Updated translations.
- Drop pkgconfig(libquvi) BuildRequires: no longer needed after
  the complete switch to totem-pl-parser (totem-plparser is already
  BuildRequired).
* Sat May 25 2013 dimstar@opensuse.org
- Update to version 0.2.8:
  + Flickr plugin: Renaming of sources created using GOA
    (bgo#700517).
  + Magnatune plugin:
  - New plugin providing music from Magnatune (bgo#698523).
  + Updated translations.
* Fri May 17 2013 dimstar@opensuse.org
- Update to version 0.2.7:
  + Fix crash when registering sources.
  + Flickr plugin: support GOA accounts.
  + LastFM Album Art plugin: Hardcode support for "mega" and
    "extra" thumbnails.
  + Metadata Store plugin: Added filtering by type.
  + Tracker plugin
  - Handle date-format keys.
  - Fix query syntax.
  + Bugs fixed: bgo#673496, bgo#697565, bgo#700297, bgo#696860,
    bgo#697175, bgo#697565, bgo#679624, bgo#696863, bgo#696864,
    bgo#697724, bgo#700297
  + Updated translations.
- Add pkgconfig(goa-1.0) and pkgconfig(oauth) BuildRequires: new
  dependencies for Flickr/GOA account integration.
- Add intltool BuildRequires: new dependency for the translations.
- Create -lang package.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 0.2.6:
  + Filesystem plugin:
  - grl-filesystem only honours the first base-path (bgo#690710).
  - Filesystem plugin strips "extension" from directories' title
    (bgo#694008).
  + Jamendo plugin: Capitalize root-level titles.
  + Metadata Store plugin:
  - Store type of media.
  - Add filter by source-id key.
  + Rai.tv plugin: New plugin that provides videos from Rai TV.
  + TMDb plugin: Several fixes: bgo#691196, bgo#691197, bgo#691339.
  + Tracker plugin:
  - Added support for Tracker 0.16.
  - Added filter by type support,
  - grilo tracker plugin doesn't notify about newly added media
    (bgo#691717).
  + UPnP plugin: Add filter by type support.
  + YouTube plugin: Initialize correctly all the inner structures.
  + LastFM Album Art plugin: Do not return default image.
  + Bugs fixed: bgo#690614, bgo#692118, bgo#695789.
- Pass --enable-raitv to configure: build the plugin (no new
  dependencies).
- Drop grilo-plugins-tracker-0.16.patch: fixed upstream.
- Drop gnome-common and gnome-doc-utils-devel BuildRequires and
  call to gnome-autogen.sh, as we no longer carry any patches.
* Sat Mar  9 2013 dimstar@opensuse.org
- Add grilo-plugins-tracker-0.16.patch: Add support for tracker
  0.16.
- Add gnome-common and gnome-doc-utils-devel BuildRequires and
  call to autoreconf, as above patch touches the build system.
- Replace pkgconfig(tracker-sparql-0.14) BuildRequires with
  tracker-devel: the .pc file change with each version of tracker.
* Mon Dec 17 2012 vuntz@opensuse.org
- Update to version 0.2.5:
  + General:
  - Moved examples/ into help/
  - Fixed typo in documentation
  - Build fix (bgo#689577)
  + TMDb plugin:
  - Do not require plugin installed to run the tests
  - Several fixes and improvements in tests
  - Publication date is a slow key
  + UPnP plugin:
  - Fixed race condition when creating the sources
- Re-enable "make check" in %%check as it works now.
* Tue Dec 11 2012 vuntz@opensuse.org
- Update to version 0.2.4:
  + General:
  - Improved build system
  - Added plugins documentation
  - grl_source_query(): Does not hint at the query syntaxes
    (bgo#685473)
  + Blip.TV plugin:
  - Use GrlNet instead of librest
  - Fixed backend API usage
  + Filesystem plugin:
  - Fixed a warning
  + Jamendo plugin:
  - Return no result when browsing out of range feeds
    (bgo#689125)
  + Local Metadata plugin:
  - Check URL in resolve
  + Metadata Store plugin:
  - Fixed crash with freed variable
  - Add 'search' with filtering by 'favourite' (bgo#687788)
  + TMDb plugin:
  - Added documentation
  - Added example of use
  - Restored original-title key
  - Add tmdb plugin tests (bgo#688245)
  + Tracker plugin:
  - Added support for Tracker 0.15
  + Vimeo plugin:
  - Use GrlNet
  - Use quvi to get the URL video
  - Set up URL key as slow key
  - Added "format" parameter
  - Vimeo plugin is broken (bgo#688821)
- Add docbook_4 and gnome-doc-utils-devel BuildRequires: new
  dependencies to build tutorial.
- Remove pkgconfig(rest-0.7) BuildRequires: dependency is now gone.
- Disable "make check" in %%check as it fails during the build. It
  likely needs the package to be installed (see bgo#690034).
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 0.2.3:
  + General:
  - Remove "default" get_caps implemetations (bgo#673491).
  - Sources report the type of medias they support.
  + DMAP plugin: Fixed typo in GObject macro.
  + Flickr plugin: Handle only photos.
  + Metadata Store plugin:
  - Updates don't work properly (bgo#686282).
  - Add support for GRL_METADATA_KEY_FAVOURITE (bgo#686288).
  + TMDb plugin: several fixes.
  + UPnP plugin: Link it to libgssdp.
  + YouTube plugin: Added "format" parameter.
- Add pkgconfig(gssdp-1.0) BuildRequires: new dependency.
* Fri Oct  5 2012 dimstar@opensuse.org
- Update to version 0.2.2:
  + TMDb plugin:
  - Added new plugin that gets information from TMDb.
- Add pkgconfig(json-glib-1.0) BuildRequires: dependencz for the
  new TMDb plugin.
* Thu Oct  4 2012 dimstar@opensuse.org
- Update to version 0.2.1:
  + DMAP plugin:
  - New plugin providing content from DMAP protocol (bgo#652516)
  + Local Metadata plugin: Fixed segmentation fault.
  + Tracker plugin: Several fixes
  + YouTube plugin: Better error reporting for youtube plugin when
    quvi fails (bgo#685235).
- Add pkgconfig(libdmapsharing-3.0) BuildRequires: dependency for
  the new DMAP plugin.
- Add pkgconfig(grilo-net-0.2) BuildRequires so it can be properly
  versioned.
* Mon Aug 13 2012 dimstar@opensuse.org
- Update to version 0.2.0:
  + General:
  - Use the new API 0.2.0
  - Added support for Windows
  + Apple trailers plugin:
  - Fixed mime-type
  + Filesystem plugin:
  - Added filtering by key capability
  - Added filtering by media type capability
  + Tracker plugin:
  - Added config option to expose documents as content
  - Merged Tracker Media Source and Tracker Metadata Source in
    one Tracker Source
  - No tracker-sparql-0.12 support (bgo#658448)
  - Support multiple resources in a larger file (bgo#662748)
  + UPnP plugin:
  - Removed "UPnP -" prefix from title
  - Empty results on UPnP shows error (bgo#653756)
  - UPnP sends back containers on search (bgo#653759)
  - Support GRL_METADATA_KEY_TRACK_NUMBER (bgo#658812)
* Mon Aug 13 2012 dimstar@opensuse.org
- Update to version 0.1.20:
  + General:
  - Remove g_thread_init() call
  - Use g_str_has_prefix() instead of strrstr()
  + Gravatar plugin:
  - Don't leak GParamSpec (bgo#680435)
* Wed Jun  6 2012 dimstar@opensuse.org
- Update to version 0.1.19:
  + General:
  - bgo#641115: grilo plugins do not store private data in right
    places
  - bgo#641357: Remove libdir= from all Makefile.am
  - bgo#667855: Support tracker 0.13/0.14
  + Filesystem plugin:
  - Do not show file extension in the media title
  + Jamendo plugin:
  - Fix small typo
  + Local Metadata plugin:
  - Several fixes and improvements
  - Use user's cache to get album art
  - bgo#673916: local-metadata: Support all GIO supported schemes
  - bgo#673936: local-metadata: Don't leave unfinished calls
  + Optical Media plugin:
  - New plugin that provides content from DVD and Blu-ray disks
    (bgo#672929)
  + SHOUTCast plugin:
  - Use the new API 2.0
  + Tracker plugin:
  - bgo#662748: tracker plugin: support multiple resources in a
    larger file
  + UPnP plugin:
  - bgo#653756: Empty results on UPnP shows error
  + Youtube plugin:
  - Request quvi 0.4.0
- Add pkgconfig(totem-plparser) BuildRequires: dependency for the
  new optical media plugin.
- Drop grilo-plugins-tracker-0.14.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh:
  as we don't carry any patches, we don't need to bootstrap.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Tue May 22 2012 dimstar@opensuse.org
- bnc#710364: Split out plugins with large (and often disputed)
  dependencies:
  - tracker
  - upnp
  - youtube
- Supplement the new packages with grilo-plugins and their
  respective functional providers.
* Thu Jan 19 2012 vuntz@opensuse.org
- Add support for tracker 0.13/0.14:
  + Add grilo-plugins-tracker-0.14.patch.
  + Add gnome-common BuildRequires and call to gnome-autogen.sh,
    needed for above patch.
  + Change pkgconfig(tracker-sparql-0.12) BuildRequires to
    pkgconfig(tracker-sparql-0.14).
* Wed Jan 11 2012 dimstar@opensuse.org
- Build against gmime 2.6: replace pkgconfig(gmime-2.4)
  BuildRequires with pkgconfig(gmime-2.4).
* Sat Dec 10 2011 dimstar@opensuse.org
- Update to version 0.1.18:
  + General:
  - Added support for Windows
  + Apple trailers plugin:
  - Fixed mime-type
  + Tracker plugin:
  - No tracker-sparql-0.12 support [bgo#658448]
  - Added config option to expose documents as content (turned
    off by default)
  + UPnP plugin:
  - Removed "UPnP -" prefix from title
  - Fix "UPnP sends back container on search" [bgo#653759]
  - Support GRL_METADATA_KEY_TRACK_NUMBER [bgo#658812]
- Drop grilo-plugins-tracker-0.12.patch: fixed upstream
- Remove gnome-common BuildRequires and call to autoreconf, as we
  don't have any patches anymore.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that...
  See bnc#697467 for more details.
* Tue Sep 13 2011 vuntz@opensuse.org
- Fix build with tracker 0.12:
  + Add grilo-plugins-tracker-0.12.patch: support build with
    tracker 0.12.
  + Change pkgconfig(tracker-sparql-0.11) BuildRequires to
    pkgconfig(tracker-sparql-0.12).
  + Add gnome-common BuildRequires and call to autoreconf, needed
    for the patch.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 0.1.17:
  + General
  - Do not generate static libraries
  - Install XML files in the same place as libraries plugins.
  + Blip.TV plugin
  - Added new plugin
  + Bookmarks plugin
  - Minor changes
  + Local Metadata plugin
  - Plugged memory leak
  + Podcasts plugin
  - bgo#653937: Doesn't support gmime 2.5.x
  + Tracker plugin
  - Minor fixes
  - bgo#654248: tracker-sparql-0.11 support
  - Removed code for tracker < 0.10.5
  + Vimeo plugin
  - Correctly links against libgcrypt
  + Youtube plugin
  - Minor fixes
  - Added support for libgdata >= 0.9.0
  - Removed code for libdata < 0.7
- Drop tracker-sparql-version.patch and
  grilo-plugins-gdata0.9.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh:
  those were only needed for the above patches.
- Add libgcrypt-devel and pkgconfig(rest-0.7) BuildRequires: new
  dependencies.
* Wed Aug  3 2011 dimstar@opensuse.org
- Spec file cleanup for inclusion into Factory.
- Add grilo-plugins-gdata0.9.patch: Fix build with gdata 0.9, taken
  from git.
* Fri Jul  8 2011 cbosdonnat@novell.com
- Added tracker-sparql-0.11 and libquvi dependencies for build on
  Factory.
* Thu Jul  7 2011 cbosdonnat@novell.com
- Initial package for grilo plugins
